@@ -5,16 +5,16 @@ import tensorflow as tf
 class Synaptic_Normalization_TF(Behaviour):
 
     def set_variables(self, neurons):
-        self.syn_type = self.get_init_attr('syn_type', 'GLU', neurons)
+        self.syn_type = self.parameter('syn_type', 'GLU', neurons)
 
         neurons.require_synapses(self.syn_type, warning=False)#suppresses error when synapse group does not exist
 
-        self.clip_min = self.get_init_attr('clip_min', 0.0, neurons)
-        self.clip_max = self.get_init_attr('clip_max', 1000000.0, neurons)
+        self.clip_min = self.parameter('clip_min', 0.0, neurons)
+        self.clip_max = self.parameter('clip_max', 1000000.0, neurons)
 
-        self.norm_factor = tf.constant(self.get_init_attr('norm_factor', 1.0, neurons), dtype='float32')
+        self.norm_factor = tf.constant(self.parameter('norm_factor', 1.0, neurons), dtype='float32')
 
-        neurons.temp_weight_sum = tf.Variable(neurons.get_neuron_vec(), dtype='float32')
+        neurons.temp_weight_sum = tf.Variable(neurons.vector(), dtype='float32')
 
     def new_iteration(self, neurons):
         neurons.temp_weight_sum.assign(tf.multiply(neurons.temp_weight_sum, 0.0))
