@@ -8,8 +8,8 @@ class Equation(Behaviour):
     def set_variables(self, neurons):
         n=neurons
         self.add_tag('EquationModule')
-        self.step_size = self.get_init_attr('step_size', '1*ms', neurons)
-        eq_parts = eq_split(self.get_init_attr('eq', None))
+        self.step_size = self.parameter('step_size', '1*ms', neurons)
+        eq_parts = eq_split(self.parameter('eq', None))
 
         if eq_parts[0][0] == 'd' and eq_parts[1] == '/' and eq_parts[2] == 'dt' and eq_parts[3] == '=':
             self.variable = eq_parts[0][1:]
