@@ -47,9 +47,6 @@ class NeuronGroup(NetworkObjectBase):
 
         self.mask = True#np.array([True for _ in range(size)]).astype(bool)#True#used for subgroup reconstruction
 
-        self.learning = True
-        self.recording = True
-
         self.id = np.arange(self.size)
 
         if color is not None:
@@ -71,23 +68,24 @@ class NeuronGroup(NetworkObjectBase):
             self.efferent_synapses[name] = []
 
 
-    def get_neuron_vec(self, mode='zeros()', scale=None, density=None, plot=False):
+    def vector(self, mode='zeros()', scale=None, density=None, plot=False):
         return self._get_mat(mode=mode, dim=(self.size), scale=scale, density=density, plot=plot)
-    
-    vector = get_neuron_vec
-    vec = get_neuron_vec
-    array = get_neuron_vec
 
-    #def get_neuron_vec(self, mode='zeros()', scale=None, density=None, plot=False, kwargs={}, args=[]):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)', ...]
+    get_neuron_vec = vector
+    vector = vector
+    vec = vector
+    array = vector
+
+    #def vector(self, mode='zeros()', scale=None, density=None, plot=False, kwargs={}, args=[]):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)', ...]
     #    return self._get_mat(mode=mode, dim=(self.size), scale=scale, density=density, plot=plot, kwargs=kwargs, args=args)
 
-    def get_neuron_vec_buffer(self, buffer_size):
+    def vector_buffer(self, buffer_size):
         return self.get_buffer_mat((self.size), buffer_size)
 
     def get_combined_synapse_shape(self, Synapse_ID):
         source_num = 0
         for syn in self.afferent_synapses[Synapse_ID]:
-            d, s = syn.get_synapse_mat_dim()
+            d, s = syn.matrix_dim()
             source_num += s
         return self.size, source_num
 
